# AutoBookingGym
one click is all you need
如果是外网环境可能会读不了cookie，读cookie需要用一个人的账户与wifi密码进到内网环境中
进到内网环境之后要重新输入预约账户的账户和密码来保存cookie

所以目前只能在内网环境下保存cookie
但是可以在外网环境下预约

草，破案了。
如果是外网环境，用自己的账号登录一遍外网资源入口
再保存cookie就可以了

所以外网环境只多了一步：提前登陆一下自己的账号

## 傻瓜使用方法：
在每天 13:00 运行 main.py 程序即可。

## 更优秀的使用方法：
如果很多人抢，那么要在 13:00 之前进行准备工作（保存cookie，提前打开浏览器）

## 实现功能
1. 若cookie过期则自动保存cookie
2. 通过全局变量HEADLESS支持浏览器无头模式
3. 增加了parallel.py模块的go()函数支持对所有用户的并行操作
4. 写一个ready文件，再写一个go文件，分批执行。
5. 去掉了日志功能
6. 增加了：“是否打印”功能。
7. 添加日志功能
8. 对log文件只保存前5个，多了就自动放到more里面。
9. 对cookie文件只保存前三个，多了就自动放到more里面。


# 下一步操作：
1. 目前只能支持校内访问，下一步要让电脑自动识别校外访问网址，能够进行校外访问。
2. 每个用户用json格式来写

